@@ -9,7 +9,7 @@ from flexget.event import event
 from flexget.utils.cached_input import cached
 from flexget.plugin import register_plugin, get_plugin_by_name, PluginError, PluginWarning, register_parser_option
 from flexget import db_schema
-from flexget.utils.tools import parse_timedelta
+from flexget.utils.tools import parse_timedelta, multiply_timedelta
 
 log = logging.getLogger('discover')
 Base = db_schema.versioned_base('discover', 0)
@@ -133,12 +133,34 @@ class Discover(object):
                 log.verbose('Searching for `%s` (%i of %i)' % (entry['title'], index, len(entries)))
                 try:
                     search_results = search.search(entry, plugin_config)
+                    if not search_results:
+                        log.debug('No results from %s' % plugin_name)
+                        entry.complete()
+                        continue
                     log.debug('Discovered %s entries from %s' % (len(search_results), plugin_name))
-                    result.extend(search_results[:config.get('limit')])
+                    if config.get('limit'):
+                        search_results  = sorted(search_results, reverse=True,
+                                                 key=lambda x: x.get('search_sort'))[:config['limit']]
+                    for e in search_results:
+                        e.on_complete(self.entry_complete, query=entry, search_results=search_results)
+                    result.extend(search_results)
+
                 except (PluginError, PluginWarning):
                     log.debug('No results from %s' % plugin_name)
+                    entry.complete()
+
         return sorted(result, reverse=True, key=lambda x: x.get('search_sort'))
 
+    def entry_complete(self, entry, query=None, search_results=None, **kwargs):
+        if entry.accepted:
+            # One of the search results was accepted, transfer the acceptance back to the query entry which generated it
+            query.accept()
+        # Remove this entry from the list of search results yet to complete
+        search_results.remove(entry)
+        # When all the search results generated by a query entry are complete, complete the query which generated them
+        if not search_results:
+            query.complete()
+
     def estimated(self, entries):
         """
         :return: Entries that we have estimated to be available
@@ -147,17 +169,20 @@ class Discover(object):
         result = []
         for entry in entries:
             est_date = estimator.estimate(entry)
-            if isinstance(est_date, datetime.date):
-                # If we just got a date, add a time so we can compare it to now()
-                est_date = datetime.datetime.combine(est_date, datetime.time())
             if est_date is None:
                 log.debug('No release date could be determined for %s' % entry['title'])
                 result.append(entry)
-            elif datetime.datetime.now() >= est_date:
-                log.info('%s has been released at %s' % (entry['title'], est_date))
+                continue
+            if type(est_date) == datetime.date:
+                # If we just got a date, add a time so we can compare it to now()
+                est_date = datetime.datetime.combine(est_date, datetime.time())
+            if datetime.datetime.now() >= est_date:
+                log.verbose('%s has been released at %s' % (entry['title'], est_date))
                 result.append(entry)
             else:
-                log.info("%s hasn't been released yet (Expected:%s)" % (entry['title'], est_date))
+                entry.reject('has not been released')
+                entry.complete()
+                log.verbose("%s hasn't been released yet (Expected:%s)" % (entry['title'], est_date))
         return result
 
     def interval_total_seconds(self, interval):
@@ -189,7 +214,7 @@ class Discover(object):
                 task.session.add(de)
             if task.manager.options.discover_now or not de.last_execution:
                 # First time we execute (and on --discover-now) we randomize time to avoid clumping
-                delta = datetime.timedelta(seconds=(random.random() * self.interval_total_seconds(interval)))
+                delta = multiply_timedelta(interval, random.random())
                 de.last_execution = datetime.datetime.now() - delta
             else:
                 next_time = de.last_execution + interval
@@ -199,13 +224,14 @@ class Discover(object):
                     log.debug('interval not met')
                     log.verbose('Discover interval %s not met for %s. Use --discover-now to override.' %
                                 (config['interval'], entry['title']))
+                    entry.reject('discover interval not met')
+                    entry.complete()
                     continue
                 de.last_execution = datetime.datetime.now()
             log.debug('interval passed')
             result.append(entry)
         return result
 
-    @cached('discover')
     def on_task_input(self, task, config):
         task.no_entries_ok = True
         entries = self.execute_inputs(config, task)
